@@ -1,4 +1,4 @@
-#! /bin/echo This file must be sourced inside (ba)sh using: .
+#   This file must be sourced inside (ba)sh using: .
 #
 #   GNUstep-reset.sh
 #
@@ -86,13 +86,13 @@ function reset_path
   fi
 }
 
-reset_path INFOPATH /Library/Documentation/info
-reset_path GUILE_LOAD_PATH /Library/Libraries/Guile
-reset_path CLASSPATH /Library/Libraries/Java
-reset_path LD_LIBRARY_PATH /Library/Libraries
-reset_path DYLD_LIBRARY_PATH /Library/Libraries
-reset_path DYLD_FRAMEWORK_PATH /Library/Frameworks
-reset_path PATH /Tools
+reset_path INFOPATH /usr/pkg/info
+reset_path GUILE_LOAD_PATH /usr/pkg/lib/Guile
+reset_path CLASSPATH /usr/pkg/lib/Java
+reset_path LD_LIBRARY_PATH /usr/pkg/lib
+reset_path DYLD_LIBRARY_PATH /usr/pkg/lib
+reset_path DYLD_FRAMEWORK_PATH /usr/pkg/lib/GNUstep/Frameworks
+reset_path PATH /usr/pkg/bin
 
 # Make sure we destroy the reset_path function after using it - we don't
 # want to pollute the environment with it.
@@ -160,6 +160,7 @@ unset GNUSTEP_USER_DOC_INFO
 
 # These should not defined, but might be if something goes wrong
 # somewhere.
+unset GNUSTEP_MAKE_STRICT_V2_MODE
 unset GNUSTEP_USER_DIR_APPS 
 unset GNUSTEP_USER_DIR_ADMIN_APPS
 unset GNUSTEP_USER_DIR_WEB_APPS
